## v6.0.2 (2023-01-16)

## v6.0.1 (2023-01-07)

## v6.0.0 (2022-10-16)

### BREAKING CHANGE

- more to latest toolbox_utils which uses pydantic

### Feat

- added python api for all command line functions and corrected calls to tsutils.printiso

### Fix

- update to latest toolbox_utils and misc. modernizations

## v5.3.2 (2022-09-28)

### Refactor

- moved from tstoolbox.tsutils to toolbox_utils.tsutils and completed pyproject.toml

## v5.3.1 (2022-07-29)

### Fix

- adopted new hspfbintoolbox format for years

### Refactor

- shifted to f strings

## v5.3.0 (2022-02-14)

### Feat

- **docstrings**: moved to using templates for docstrings

### Refactor

- docsrc -> docs

## v5.2.2 (2021-08-01)

### Fix

- adjust some water balance terms.

## v5.2.1 (2021-06-09)

## v5.1.1 (2020-04-30)

### Fix

- Fix deprecated pandas .ix

## v4.2.1.2 (2020-03-17)
